pub const fn bits<T: UnsignedPrimInt>() -> u32Expand description
Determine the number of bits needed to represent the specified UnsignedPrimInt.
pub const fn bits<T: UnsignedPrimInt>() -> u32Determine the number of bits needed to represent the specified UnsignedPrimInt.