checked_sub

Function checked_sub 

pub fn checked_sub<T: UnsignedPrimInt>(left: T, right: T) -> Option<T>
👎Deprecated:

Use primint :: checked_sub directly.

An alias for [primint :: checked_sub].

This is logically a re-export, but a wrapper function is used instead as re-exports can’t currently be deprecated (rust-lang/rust#30827)

This function will be removed in the next semver-breaking release.