max_value

Function max_value 

pub const fn max_value<T: UnsignedPrimInt>() -> T
👎Deprecated:

Use primint :: max_value directly.

An alias for [primint :: max_value].

This is logically a re-export, but a wrapper function is used instead as re-exports can’t currently be deprecated (rust-lang/rust#30827)

This function will be removed in the next semver-breaking release.