zero

Function zero 

pub const fn zero<T: UnsignedPrimInt>() -> T
👎Deprecated:

Use primint :: zero directly.

An alias for [primint :: zero].

This is logically a re-export, but a wrapper function is used instead as re-exports can’t currently be deprecated (rust-lang/rust#30827)

This function will be removed in the next semver-breaking release.