UnsignedPrimInt

Trait UnsignedPrimInt 

pub trait UnsignedPrimInt: UnsignedPrimInt { }
👎Deprecated:

Use primint::UnsignedPrimInt directly

A trait alias for primint::UnsignedPrimInt.

This is logically a re-export, but a wrapper function is used instead as re-exports can’t currently be deprecated (rust-lang/rust#30827)

Since trait aliases are not usable on stable rust, we use a blanket impl and trait bound instead.

This trait alias will be removed in the next semver-breaking release.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors