pub struct OrderByInt<T: IntegerId>(pub T);Expand description
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: IntegerId> AsMut<T> for OrderByInt<T>
impl<T: IntegerId> AsMut<T> for OrderByInt<T>
Sourceimpl<T: IntegerId> AsRef<T> for OrderByInt<T>
impl<T: IntegerId> AsRef<T> for OrderByInt<T>
Sourceimpl<T: Clone + IntegerId> Clone for OrderByInt<T>
impl<T: Clone + IntegerId> Clone for OrderByInt<T>
Sourcefn clone(&self) -> OrderByInt<T>
fn clone(&self) -> OrderByInt<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T: Copy + IntegerId> Copy for OrderByInt<T>
Sourceimpl<T: Default + IntegerId> Default for OrderByInt<T>
impl<T: Default + IntegerId> Default for OrderByInt<T>
Sourcefn default() -> OrderByInt<T>
fn default() -> OrderByInt<T>
Returns the “default value” for a type. Read more
impl<T: IntegerId> Eq for OrderByInt<T>
Sourceimpl<T: IntegerId> EquivalentId<T> for OrderByInt<T>
impl<T: IntegerId> EquivalentId<T> for OrderByInt<T>
Sourceimpl<T: IntegerId> EquivalentId<T> for &OrderByInt<T>
impl<T: IntegerId> EquivalentId<T> for &OrderByInt<T>
Sourceimpl<T: IntegerId> From<T> for OrderByInt<T>
impl<T: IntegerId> From<T> for OrderByInt<T>
Sourceimpl<T: IntegerId> Hash for OrderByInt<T>
impl<T: IntegerId> Hash for OrderByInt<T>
Sourceimpl<T: IntegerId> IntegerId for OrderByInt<T>
impl<T: IntegerId> IntegerId for OrderByInt<T>
Sourceconst MIN_ID: Option<Self>
const MIN_ID: Option<Self>
The value of this type with the smallest integer value,
or
None if this type is uninhabited.Sourceconst MAX_ID: Option<Self>
const MAX_ID: Option<Self>
The value of this type with the largest integer value,
or
None if this type is uninhabited.Sourceconst MIN_ID_INT: Option<Self::Int> = <T as crate::IntegerId>::MIN_ID_INT
const MIN_ID_INT: Option<Self::Int> = <T as crate::IntegerId>::MIN_ID_INT
Sourceconst MAX_ID_INT: Option<Self::Int> = <T as crate::IntegerId>::MAX_ID_INT
const MAX_ID_INT: Option<Self::Int> = <T as crate::IntegerId>::MAX_ID_INT
Sourceconst TRUSTED_RANGE: Option<TrustedRangeToken<Self>>
const TRUSTED_RANGE: Option<TrustedRangeToken<Self>>
Indicates that the type’s implementation of
IntegerId::to_int can be trusted
to only return values in the range MIN_ID_INT..=MAX_ID_INT. Read moreSourcefn from_int(id: Self::Int) -> Self
fn from_int(id: Self::Int) -> Self
Create an id from the underlying integer value,
panicking if the value is invalid. Read more
Sourcefn from_int_checked(id: Self::Int) -> Option<Self>
fn from_int_checked(id: Self::Int) -> Option<Self>
Create an id from the underlying integer value,
returning
None if the value is invalid.Sourceunsafe fn from_int_unchecked(id: Self::Int) -> Self
unsafe fn from_int_unchecked(id: Self::Int) -> Self
Create an id from the underlying integer value,
triggering undefined behavior if the value is invalid. Read more
impl<T: IntegerIdContiguous> IntegerIdContiguous for OrderByInt<T>
Sourceimpl<T: IntegerIdCounter> IntegerIdCounter for OrderByInt<T>
impl<T: IntegerIdCounter> IntegerIdCounter for OrderByInt<T>
Sourceimpl<T: IntegerId> Ord for OrderByInt<T>
impl<T: IntegerId> Ord for OrderByInt<T>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T: IntegerId> PartialEq for OrderByInt<T>
impl<T: IntegerId> PartialEq for OrderByInt<T>
Sourceimpl<T: IntegerId> PartialEq<T> for OrderByInt<T>
impl<T: IntegerId> PartialEq<T> for OrderByInt<T>
Sourceimpl<T: IntegerId> PartialOrd for OrderByInt<T>
impl<T: IntegerId> PartialOrd for OrderByInt<T>
Sourceimpl<T: IntegerId> PartialOrd<T> for OrderByInt<T>
impl<T: IntegerId> PartialOrd<T> for OrderByInt<T>