TrustedRangeToken

Struct TrustedRangeToken 

pub struct TrustedRangeToken<T: IntegerId> { /* private fields */ }
Indicates that an IntegerId unsafely guarantees that the result of IntegerId::to_int will always fall in the range IntegerId::MIN_INT..=IntegerId::MAX_ID.

Also guarantees that the IntegerId::to_int is implemented in the expected manner.

Just because the type implements something like bytemuck::Contiguous does not mean that it is valid to create the token, as IntegerId::to_int could still be implemented incorrectly.

Implementations

Source

impl<T: IntegerId> TrustedRangeToken<T>

pub const unsafe fn assume_valid() -> Self

Promise that the type T satisfies the appropriate correctness requirements.

Safety

If the IntegerId does not meet the requirements, this is immediate undefined behavior (similar to constructing a ! type).

pub const unsafe fn assume_valid_if<U: IntegerId>() -> Option<Self>

Promise that the type T satisfies the appropriate correctness whenever U promises to.

This function is helpful for implementing newtype wrappers around an arbitrary inner type.

This is equivalent to T::TRUSTED_RANGE::map(|| unsafe { TrustedRangeToken::assume_valid() }), but works in a const context.

Safety

You must ensure that U can be trusted with the requirements of TrustedRangeToken whenever U meets those same requirements.