bits

Function bits 

pub const fn bits<T: UnsignedPrimInt>() -> u32
👎Deprecated:

Use primint :: bits directly.

An alias for [primint :: bits].

This is logically a re-export, but a wrapper function is used instead as re-exports can’t currently be deprecated (rust-lang/rust#30827)

This function will be removed in the next semver-breaking release.