debug_desc

Function debug_desc 

pub fn debug_desc<T: UnsignedPrimInt>(value: T) -> DebugDesc<T>
👎Deprecated:

Use primint::fmt::debug_desc directly.

An alias for primint::fmt::debug_desc.

This is logically a re-export, but a wrapper function is used instead as re-exports can’t currently be deprecated (rust-lang/rust#30827)

This function will be removed in the next semver-breaking release.