pub trait UnsignedPrimInt:
Eq
+ Hash
+ Ord
+ Copy
+ Default
+ Debug
+ Display
+ ConvertPrimInts
+ PrivateUnsignedInt
+ MaybeNumTrait
+ MaybePod
+ MaybeContiguous { }Expand description
An unsigned primitive integer.
Most methods in this trait are only available through the intid::uint module
in order to avoid conflict with inherit implementations and other traits.
You can get access to more functionality by enabling the num-traits or bytemuck features,
which will add num_traits::PrimInt and bytemuck::Pod bounds respectively.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".